Summary: The GNU shar utilities for packaging and unpackaging shell archives.
Name: sharutils
Version: 4.2.1
Release: 1
Copyright: GPL
Group: Applications/Archiving
Source: ftp://prep.ai.mit.edu/pub/gnu/sharutils/sharutils-%{version}.tar.gz
Patch0: sharutils-%{version}-fixnl.patch
Prefix: %{_prefix}
Prereq: /sbin/install-info
Buildroot: /var/tmp/%{name}-root

%ifarch ia64
%define DEFCCIA cc
%define DEFCC %{DEFCCIA}
%else
%define DEFCC cc
%endif

%description
The sharutils package contains the GNU shar utilities, a set of tools
for encoding and decoding packages of files (in binary or text format)
in a special plain text format called shell archives (shar).  This
format can be sent through e-mail (which can be problematic for regular
binary files).  The shar utility supports a wide range of capabilities
(compressing, uuencoding, splitting long files for multi-part
mailings, providing checksums), which make it very flexible at
creating shar files.  After the files have been sent, the unshar tool
scans mail messages looking for shar files.  Unshar automatically
strips off mail headers and introductory text and then unpacks the
shar files.

Install sharutils if you send binary files through e-mail.

%prep
%setup -q
%patch0 -p1 -b .nl

%build
# Use the default compiler for this platform - gcc otherwise
if [[ -z "$CC" ]]
then
    if test "X`type %{DEFCC} 2>/dev/null`" != 'X'; then
       export CC=%{DEFCC}
    else 
       export CC=gcc
    fi
fi
if test "X$CC" != "Xgcc"
then
       export RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS | sed 's:-fsigned-char::'`
fi
export CFLAGS="$RPM_OPT_FLAGS -D_LARGE_FILES"

# Add /bin in front of /usr/bin so that it will configure bash as
# /bin/bash instead of /usr/bin/bash
NEWPATH=`echo $PATH | sed -e 's,^/usr/bin,/bin:/usr/bin,' \
-e 's,:/usr/bin,:/bin:/usr/bin,'`
export PATH=$NEWPATH
CFLAGS="$CFLAGS" LDFLAGS=-s ./configure --prefix=%{_prefix} --with-gnu-gettext

make

%install
rm -rf ${RPM_BUILD_ROOT}

make prefix=${RPM_BUILD_ROOT}%{_prefix} install install-man
gzip -9nf ${RPM_BUILD_ROOT}%{_prefix}/info/sharutils*
gzip -9nf ${RPM_BUILD_ROOT}%{_prefix}/info/remsync*

/usr/bin/strip ${RPM_BUILD_ROOT}%{_prefix}/bin/* 2>/dev/null || :

(cd $RPM_BUILD_ROOT
    mkdir -p usr/bin
    cd usr/bin
    ln -sf ../..%{_prefix}/bin/* .
    rm uu*
    cd -
    mkdir -p usr/linux/bin
    cd usr/linux/bin
    ln -sf ../../..%{_prefix}/bin/uu* .
)
%post
/sbin/install-info %{_prefix}/info/sharutils.info.gz %{_prefix}/info/dir

%preun
if [ $1 = 0 ]; then
    /sbin/install-info --delete %{_prefix}/info/sharutils.info.gz %{_prefix}/info/dir
fi

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
/usr/bin/*
/usr/linux/bin/*
%{_prefix}/bin/*
%{_prefix}/info/sharutils*
%{_prefix}/info/remsync*
%{_prefix}/man/*/*
%{_prefix}/share/locale/*/*/*

%changelog
* Tue Aug 14 2001 David Clissold <cliss@austin.ibm.com>
- Update to version 4.2.1

* Tue Apr 03 2001 David Clissold <cliss@austin.ibm.com>
- Build with -D_LARGE_FILES enabled (for >2BG files)

* Fri Mar 23 2001 Marc Stephenson <marc@austin.ibm.com>
- Rebuild against new shared objects
- Use default compiler
- Find /bin/bash instead of /usr/bin/bash

* Mon Feb 07 2000 Preston Brown <pbrown@redhat.com>
- rebuild to gzip man pages

* Tue Dec 21 1999 Preston Brown <pbrown@redhat.com>
- sharutils 4.2.1 for Y2K (2 digit date) fix.
- ja message catalog move (#7878)

* Tue Sep  7 1999 Jeff Johnson <jbj@redhat.com>
- handle spaces in uuencoded file names (David Fox <dsfox@cogsci.ucsd.edu>).

* Wed Jul 28 1999 Cristian Gafton <gafton@redhat.com>
- use the /usr/share/locale for the localedir instead of /usr/lib/locale
  (#2998)

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 12)

* Wed Dec 30 1998 Cristian Gafton <gafton@redhat.com>
- build for glibc 2.1

* Fri Apr 24 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Sat Apr 11 1998 Cristian Gafton <gafton@redhat.com>
- manhattan rebuild

* Fri Oct 17 1997 Donnie Barnes <djb@redhat.com>
- ALRIGHT!  Woo-hoo!  Erik already did the install-info stuff!
- added BuildRoot
- spec file cleanups

* Sun Sep 14 1997 Erik Troan <ewt@redhat.com>
- uses install-info

* Fri Jul 18 1997 Erik Troan <ewt@redhat.com>
- built against glibc

